@@ -5,13 +5,26 @@ import ai_hub.globalvar as gl
 
 app = Flask("tccapi")
 
+def shutdown_server():
+    func = request.environ.get('werkzeug.server.shutdown')
+    if func is None:
+        raise RuntimeError('Not running with the Werkzeug Server')
+    func()
+
+@app.route('/shutdown', methods=['POST'])
+def shutdown():
+    shutdown_server()
+    return 'Server shutting down...'
 
 @app.route("/tccapi", methods=['GET', 'POST'])
 def tccapi():
     ret = ""
     if request.method== 'POST':
-        #data = request.get_data()
-        #print("data: ", data)
+        data = request.get_data()
+        if data == b"exit":
+            print("Server shutting down...")
+            shutdown_server()
+            return "Server shutting down..."
 
         # inferserver
         #myinserver = gl.get_value("myinserver")
@@ -25,7 +38,7 @@ def tccapi():
             ret = str(ret)
         print("return: ", ret)
     else:
-        print("please use post request.such as ：curl localhost:8080/tccapi -X POST -d \'{\"img\"/:2}\'")
+        print("please use post request. such as : curl localhost:8080/tccapi -X POST -d \'{\"img\"/:2}\'")
     return ret
 
 
